@@ -4,6 +4,7 @@ import os
 
 import tornado.template
 import tornado.web
+from tornado.escape import _unicode
 
 from dorothy.settings import settings
 from dorothy.lib import xjson
@@ -62,9 +63,12 @@ class MainBaseHandler(tornado.web.RequestHandler):
         '''
         pass
 
-    def _handle_request_exception(self, e):
-        self._error = True
-        raise e
+    def _handle_missing_params(self, missing):
+        self.error(400, 'Missing required parameter(s) ({0})'.format(', '.join(missing)))
+
+    # def _handle_request_exception(self, e):
+    #     self._error = True
+    #     raise e
         # if isinstance(e, tornado.web.HTTPError):
         #     response = e.log_message
         #     code = e.status_code
@@ -111,6 +115,7 @@ class MainBaseHandler(tornado.web.RequestHandler):
         pass
 
     def http_error(self, code, message=None):
+        self._error = True
         raise tornado.web.HTTPError(code, message)
 
     def error(self, code, message=None):
@@ -179,8 +184,7 @@ class MainBaseHandler(tornado.web.RequestHandler):
             for p in params:
                 name, val = p.split('=', 2)
                 name = name.strip()
-                val = val.strip() if isinstance(val, basestring) else val
-                self.query[name] = val
+                self.query[name] = self.decode_arguments(val)
 
     def _parse_body(self):
         if self.request.headers.get('Content-Type') == 'application/json':
@@ -188,10 +192,42 @@ class MainBaseHandler(tornado.web.RequestHandler):
             body = xjson.loads(body)
         else:
             body = {i2[0]: i2[1] for i2 in [i.split('=') for i in self.request.body.split('&') if i]}
-        for name, val in body.iteritems():
-            name = name.strip()
-            val = val.strip() if isinstance(val, basestring) else val
-            self.body[name] = val
+
+        self.body = self.decode_arguments(body)
+
+    def decode_arguments(self, val):
+        single = False
+        if not isinstance(val, (list, dict)):
+            val = [va]
+            single = True
+
+        dict_ = False
+        if isinstance(val, dict):
+            val = val.items()
+            dict_ = True
+
+        response = []
+        for item in val:
+            _v = item if not dict_ else item[1]
+
+            if isinstance(_v, (list, dict)):
+                _v = self.decode_argument(_v)
+            elif isinstance(_v, unicode):
+                _v = RequestHandler._remove_control_chars_regex.sub(" ", _v)
+            if isinstance(_v, bytes):
+                _v = _v.decode('utf-8')
+
+            if dict_:
+                name = item[0].strip()
+                response.append((name, _v))
+            else:
+                response.append(_v.strip() if isinstance(_v, basestring) else _v)
+
+        if single:
+            return response[0]
+        if dict_:
+            return {i[0]: i[1] for i in response}
+        return response
 
 
 class WebBaseHandler(MainBaseHandler):
@@ -270,6 +306,7 @@ class ApiBaseHandler(MainBaseHandler):
             self.set_header('Content-Type', 'text/plain')
 
     def error(self, code, message):
+        self._error = True
         raise ApiError(code, message)
 
     def _respond(self, response):
