@@ -14,7 +14,7 @@ def require_params(*args, **kwargs):
                 if param not in req_args or req_args[param] is None:
                     missing.append(param)
             if missing:
-                self.error(400, 'Missing required parameter(s) ({0})'.format(', '.join(missing)))
+                self._handle_missing_params(missing)
             return fn(self, *args)
         return wrapper
     return wrapper_a
