@@ -2,7 +2,7 @@ import os
 
 import logging
 
-from dorothy.lib.util import parse_config, AttrDict
+from dorothy.lib.util import parse_config, to_attr_dict, AttrDict
 from dorothy.lib.exceptions import SettingsError
 
 
@@ -29,8 +29,12 @@ class _Settings(object):
         if name == 'config' and self.__dict__['__is'] == self.DATA:
             if self.__dict__['__config'] is None:
                 self.__dict__['__config'] = self.__class__(parse_config(self.environment), is_config=True)
-            return self.__dict__['__config']
-        return self.__dict__['__data'][name]
+            val = self.__dict__['__config']
+        else:
+            val = self.__dict__['__data'][name]
+        if isinstance(val, dict):
+            val = to_attr_dict(val)
+        return val
 
     def __setattr__(self, name, val):
         self.__dict__['__data'][name] = val
